@@ -31,7 +31,7 @@ const (
 	pathGetMessages   = "/robustirc/v1/%s/messages?lastseen=%s"
 )
 
-const Version = "RobustIRC Bridge v1.5"
+const Version = "RobustIRC Bridge v1.7"
 
 type robustId struct {
 	Id    int64
@@ -222,6 +222,10 @@ type RobustSession struct {
 	// if non-empty.
 	ForwardedFor string
 
+	// BridgeAuth will be sent in all HTTP requests as X-Bridge-Auth header if
+	// non-empty. See https://github.com/robustirc/robustirc/issues/122
+	BridgeAuth string
+
 	sessionAuth string
 	deleted     bool
 	done        chan bool
@@ -244,6 +248,9 @@ func (s *RobustSession) sendRequest(method, path string, data []byte) (string, *
 		if s.ForwardedFor != "" {
 			req.Header.Set("X-Forwarded-For", s.ForwardedFor)
 		}
+		if s.BridgeAuth != "" {
+			req.Header.Set("X-Bridge-Auth", s.BridgeAuth)
+		}
 		req.Header.Set("Content-Type", "application/json")
 		resp, err := s.client.Do(req)
 		if err != nil {
